Known Anthropic Claude models.
For unlisted models use CustomModel:
CustomModel('claude-opus-5')
Properties
-
capabilities
→ Set<Capability>
-
The capabilities supported by this model, if known.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ String
-
The raw model string sent to the API.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
supports(Capability capability)
→ bool
-
Returns true if this model supports the given capability.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
haiku45
→ const ClaudeModel
-
Claude Haiku 4.5 — fastest, most affordable Claude model.
-
opus46
→ const ClaudeModel
-
Claude Opus 4.6 — highest quality Claude model.
-
sonnet46
→ const ClaudeModel
-
Claude Sonnet 4.6 — balanced speed and quality. Default for
ClaudeEngine.